fisx: Class Members - Functions

fisx

### - g -

- getActiveArea() : fisx::Detector
- getAtomicMass() : fisx::Element , fisx::Elements
- getAtomicNumber() : fisx::Element , fisx::Elements
- getAttenuators() : fisx::XRF
- getAugerRatios() : fisx::Shell
- getBeam() : fisx::Beam , fisx::XRF , fisx::XRFConfig
- getBeamAsDoubleVectors() : fisx::Beam
- getBeamFilters() : fisx::XRF
- getBindingEnergies() : fisx::Element , fisx::Elements
- getCacheSize() : fisx::Element , fisx::Elements
- getColumn() : fisx::Element , fisx::Elements
- getComposition() : fisx::Elements , fisx::Layer , fisx::Material
- getCompositionFromFormula() : fisx::Elements
- getConfiguration() : fisx::XRF
- getCosterKronigRatios() : fisx::Shell
- getDensity() : fisx::Element , fisx::Elements
- getDetector() : fisx::XRF
- getDiameter() : fisx::Detector
- getDirectVacancyTransferRatios() : fisx::Shell
- getDistance() : fisx::Detector
- getElement() : fisx::Elements
- getElementCopy() : fisx::Elements
- getElementNames() : fisx::Elements
- getEmittedXRayLines() : fisx::Element , fisx::Elements
- getEscape() : fisx::Detector , fisx::Elements
- getEscapePeakEnergyThreshold() : fisx::Detector
- getExcitationFactors() : fisx::Elements
- getExcitedShells() : fisx::Element
- getExpectedPrimaryEmission() : fisx::XRF
- getFluorescenceRatios() : fisx::Element , fisx::Shell
- getFWHM() : fisx::Math
- getGeometricEfficiency() : fisx::XRF
- getInitialPhotoelectricVacancyDistribution() : fisx::Element , fisx::Elements
- getInterpolationIndices() : fisx::Element
- getLongName() : fisx::Element , fisx::Elements
- getMassAttenuationCoefficients() : fisx::Element , fisx::Elements , fisx::Layer
- getMaterial() : fisx::Elements , fisx::Layer
- getMaterialCopy() : fisx::Elements
- getMaterialNames() : fisx::Elements
- getMultilayerFluorescence() : fisx::XRF
- getName() : fisx::Element
- getNonradiativeTransitions() : fisx::Elements
- getPartialPhotoelectricMassAttenuationCoefficients() : fisx::Element
- getPeakFamilies() : fisx::Elements , fisx::Layer
- getPhotoelectricExcitationFactors() : fisx::Element
- getRadiativeTransitions() : fisx::Elements
- getRow() : fisx::Element , fisx::Elements
- getSample() : fisx::XRF
- getSections() : fisx::SimpleIni
- getShellConstants() : fisx::Elements
- getShellConstantsFile() : fisx::Elements
- getShellNonradiativeTransitionsFile() : fisx::Elements
- getShellRadiativeTransitionsFile() : fisx::Elements
- getSubsections() : fisx::SimpleIni
- getTransitionEnergy() : fisx::Element
- getTransmission() : fisx::Layer , fisx::TransmissionTable
- getTransmissionTable() : fisx::TransmissionTable
- getUserAttenuators() : fisx::XRF
- getUserBeamFilters() : fisx::XRF
- getXRayLines() : fisx::Element
- getXRayLinesFromVacancyDistribution() : fisx::Element , fisx::Elements